@@ -2,22 +2,22 @@
 Custom exceptions for the Basicmicro package.
 """
 
-class BasBasicmicroError(Exception):
+class BasicmicroError(Exception):
     """Base exception for all Basicmicro-related errors."""
     pass
 
 
-class CommunicationError(BasBasicmicroError):
+class CommunicationError(BasicmicroError):
     """Exception raised for errors in the communication with the controller."""
     pass
 
 
-class CommandError(BasBasicmicroError):
+class CommandError(BasicmicroError):
     """Exception raised when a command is invalid or cannot be executed."""
     pass
 
 
-class ResponseError(BasBasicmicroError):
+class ResponseError(BasicmicroError):
     """Exception raised when a response from the controller is invalid."""
     pass
 
